@@ -50,7 +50,7 @@ class CGPConnector:
                 full += msg
                 
                 if full.endswith('\r\n'.encode()):
-                    message['body'] = full.decode()[:-2]
+                    message['body'] = full.decode('utf-8')[:-2]
                     break
     
             except ConnectionAbortedError:
