@@ -59,6 +59,14 @@ def parse_to_python_object(string):
             date, src = match.groups()
             yield datetime.strptime(date, '#T%d-%m-%Y_%H:%M:%S'), src
 
+    xml_regex = re.compile(r"(<.+?>)([;,].*)", re.DOTALL)
+    
+    def parse_xml(src):
+        match = xml_regex.match(src)
+        if match is not None:
+            xml, src = match.groups()
+            yield xml, src
+    
     ip_regex = re.compile(r"#I\[([a-zA-Z0-9.:]*)](?::(\d+))?(.*)", re.DOTALL)
 
     def parse_ip(src):
@@ -75,8 +83,8 @@ def parse_to_python_object(string):
             sert, src = match.groups()
             yield sert, src
 
-    quoted_regex = re.compile(r"^\"(.*?(?<!\\))\"(.*)", re.DOTALL)
-    unquoted_regex = re.compile(r"^([\w.@#-]+)(.*)", re.DOTALL)
+    quoted_regex = re.compile(r"\"(.*?(?<!\\))\"(.*)", re.DOTALL)
+    unquoted_regex = re.compile(r"([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
         match = quoted_regex.match(src)
@@ -100,17 +108,20 @@ def parse_to_python_object(string):
     parse_true = parse_word("true", True)
     parse_false = parse_word("false", False)
     parse_null = parse_word("null", None)
+    parse_num_null = parse_word("#NULL#", None)
 
     def parse_value(src):
         for match in chain(
             parse_number(src),
-            parse_ip(src),
-            parse_datablock(src),
             parse_date(src),
             parse_true(src),
             parse_false(src),
             parse_null(src),
+            parse_num_null(src),
+            parse_ip(src),
+            parse_datablock(src),
             parse_string(src),
+            parse_xml(src),
             parse_array(src),
             parse_object(src),
             ):
@@ -239,6 +250,6 @@ def parse_to_CGP_object(python_object):
         return "false"
         
     elif python_object is None:
-        return "null"
+        return "#NULL#" # "null"
         
-    return result
\ No newline at end of file
+    return result
